
# q-expansion of newform 75.14.a.e, downloaded from the LMFDB on 01 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 75
weight = 14
poly_data = [-492, -1, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0], 1], [[-3, 6], 1]]

hecke_ring_character_values = None
aps_data = [[27, -1], [-729, 0], [0, 0], [10504, 3456], [336204, -36608], [-8766302, -89856], [-41919282, -72960], [128146772, 767232], [-429790968, 3697408], [-2364237666, 6108544], [-2991275824, 35040384], [-13705597046, 17335296], [7629487146, 98057984], [5657249620, 311613696], [34517571120, -690673408], [113168447082, 1307299968], [-463910412132, -397652992], [89697730670, 1553776128], [349157530588, -6092098560], [-392229274968, -4890812160], [-928700122538, 7102660608], [-357012735040, -1007856000], [2287146958956, 1485492992], [1635089350842, 22362004992], [4937463078238, 37066775040], [1066767259014, -93619307648], [-9161922552440, -41059661184], [-9759881689740, -16486553088], [857515321982, 160962723072], [5070000197646, -75044177408], [-34132119546512, -12119725440], [-25169585207580, 129686755328], [33470921132982, -786258631936], [72690327956588, 53774696448], [69624864284886, -700125960064], [91765793303432, 149880965760], [-65018329006478, -823828202496], [197475582244444, 935271256320], [301071480864984, -1679168728064], [-512025326772174, -1031295388288], [-236535607752300, -2840247966720], [197783844317606, -514817462016], [-503177356380096, -2585016286208], [308410290368446, 6661064650752], [-1112016906307494, -2754446512512], [853732547267096, -455995350144], [486401435868596, 432441345024], [-1715609383614512, 2394894847104], [1876418404752924, -5449809028864], [-1173129478892842, -14190808995072], [969361572989430, 25502654931456], [-1036303447501008, 8531478605312], [-1629476032111246, 22514371932672], [300510175913532, -36541482581760], [261317913957630, -47785475821568], [-4223834510514696, -25395321702400], [7432839167159502, -36203829936768], [-4309072788272416, -30645132236928], [-5036055116267654, -54463735003392], [-6581377903406022, -20215022618624], [285505569241348, -102420928106496], [-14005357308742086, 9149976277120], [-342499853548820, -8948274674688], [-3925493814515976, -10830294404608], [-1391914617122906, 22590204549120], [-4771883886689790, 129092546156672], [20734468288158572, -43666879818240], [8695708755211246, 171108681043968], [-12166040821209372, 273566847128320], [15384796794439694, 25234374680064], [34197706577254878, -20237301945856], [10338513634878408, -95239960219392], [-27026450106172064, -153508732371072], [422794492561210, 75335772335616], [-63886129453811140, 189421488057600], [-90847007930261376, -131956955955200], [-68885944215641082, -210355314564992], [15325228969184770, 30705967130112], [16072723215595890, -872754024984832], [-67461547860987142, 342532057471488], [-34427802919474908, 202875204768512], [27477856909011158, -1017338257592064], [-84386036320829424, 895342225676544], [-78085720069100786, 716057857428480], [85744491386582600, 1181166110386560], [-48407014034214012, 1209582178237184], [91357082195514786, 338952956119296], [-319397923099792106, 65629586244096], [-81278007416236818, -1202425746416000], [-23879583429355040, 296619261918336], [59956332848396460, -1294193689621248], [-229319440510150080, 1878147492778240], [159772580823692968, -998490026471040], [111339536499806220, 316287876781568], [110161583942912852, -2554591497781248], [-15962983611561432, 2602176501805824], [-280992650173627842, -1740729803162752], [336051625727430666, 1858577316766464], [-405716919289201100, -3672746352002304], [-444232184265304594, -3008876100062976], [-143425603930443236, -3922683893362944], [-390336661827482382, 2239709105343360], [488726871313167756, 1969330914433792], [-21536603604118278, -5685389069873408], [-263291219335649956, -2300930855797248], [331168428177911998, -7828062584371200], [795596482539289620, 755603459835392], [267042307207508910, 10288534162807296], [12230343981851256, 6922966011896576], [1280133425824759034, 122462900739072], [217414611092481808, -268246840406400], [-929926266163215734, 9425157503427072], [-184698471147247818, 66313318011904], [-253231209331253812, -3239475716754432], [-34544035926826648, -8761168084878720], [326420862726740706, 19903505036971264], [1442101167386252860, -8993661549421824], [743951130553709208, 15547194516775680], [879642667296199314, -9225470345490560], [2287107160095168180, 1699976921797120], [-565412764763221978, -20955509772456960], [3939788994733874782, 5192299600478208], [-2290960998625489254, 8095824653487488], [-4836135074025480876, 1418389341768960], [958057713985704884, -21702812719972608], [-1654998743668398210, 10556871889350528], [1128823489525234742, 24120516297284352], [106799210446659696, 27383609244178176], [2008874377718832952, 16384534155586944], [-3065589831168019310, 7617358543723776], [2450993395325951108, -2666822633667072], [4110878756655143640, 4499045958724096], [1202449722173007584, 20898983834612352], [-2720204086405438118, 13962241844999424], [-3135768233214706182, 421811171998976], [1956502929000762626, 37134564709671936], [1117740833349067674, -36793751806688640], [2772278588386982380, -40565876965555968], [-5256422048390267070, 40167581812961152], [8575243633218301290, -8328877223443200], [-2936333729423329108, 22374031763808000], [-117646772694827562, -6575675155677824], [-6721599927804462824, 35829697342407552], [3392872379831573028, -50869750798164480], [-1491900610950522610, -31700523192595200], [-4925032027879904280, 90694315193132800], [16406706053120071834, -32639167332218880], [-1447814183044081050, 49776549516353792], [-1706635090543710820, -114672395473862400], [15563629236512962080, 26891880665711616], [5300862386961920674, -11318131651981824], [8072547663228118578, -32406260133633024], [-9986230411980922100, 677525022049536], [-5846836416374814840, -42952849544204288], [-3601640015531279180, -176102812951504128], [-18607707480109142448, -65054423513331200], [25245362826411811400, 10555954203047040], [-2271801405690447678, -128149489621476608], [9614727414959543926, -129184887435835392], [-22291988647457657394, 90447389494135424], [-24276620893821347988, -43796810389206016], [-6434281541404773882, 50134884617059584], [-10134913428196336472, 149054492461921920], [6964255569080065356, 112245776551597824], [-39408298424199081522, -106831385377391360], [3284164598280593832, -139034549010998272], [1908726462987388112, 26056151775642240], [10430165006830495882, -56982570174521856], [25011050947698742130, 69967812074365440], [-5209283607415663734, 16631284953177472], [-14901185917568573028, -94279469740410368], [1900174525591866350, 129990572804855808], [34271096731315209288, -55977544167115264], [-22784337665559642986, 256526191883796480], [-25724992065514949056, 280267848479574144], [-32840504043544166598, 110906314790008832], [-57280034786921710084, -85049428629528576], [-2494055210582664666, -257018091912728448], [-31600686801609028280, -427687706656358784], [18981828774692392670, 502174965050496000], [-303322482205847216, 748778854332721536], [67265917763908674564, 91212817204463872], [-73185835159781692214, 26474722884663552], [18735069071188528470, -121632163283079168], [-2301330503898208080, -399780058969677824], [-40743416904219372330, 189170261310183040], [-14768319225210550382, 356858018740097280], [-108516007530098851652, 111333526667725824], [-16005557377400210806, -813598879404197376], [504839118112656768, 518340431317088256], [56165846834115355390, -319644588232387584], [81880457468231383956, 411398118565978112], [79850312542882602740, -63323781512804352], [28561920886582757694, 325750611428593792], [-97233101522339502852, -378251021895690240], [6749085812198945526, 524586039197903872], [-27578208692857559566, 1178673637326815232], [-91765323112052539214, -91724241294044928], [-99726377409302463810, 873103174205668352], [-16678217604118809096, -354569318044884480], [53431080016952744046, 51699241050382976], [-21092354794240127200, 786162093881332608], [-125472122697158151494, 692382108530181888], [33444084030409177442, -667295809850861568], [-152470858156872769044, 484821981763259136], [-164330770397575435326, -114633088034081664], [-86427181982569322608, -993931760424025728], [123272400484661389884, -447350708837454080], [81632365764425174826, 424819966923690496], [-20325099575927961652, 312332345926016256], [78886660885387247662, -254970776397136896], [-25364032675795471338, -1588125499395614080], [-46008019604484352808, 859992438259663488], [276282420696251723268, -213229160175953920], [153442009385756608968, -661248803351832832], [-152767828363785651190, -1597844388560090112], [190912385304795366112, -418782864508891776], [-79626503377190010510, 123523136236772608], [-166279464756932721624, 23881626046000128], [3269983964769832770, -298775774317779584], [-130147726927333693162, 458222470909814016], [175930760333128235144, 1173152530362271104], [46328572159745447970, 1367745556209201920], [138502079000515466656, 1121644633086767232], [205179250743852092460, -1713862041008530688], [1506937228673114150, -1263906124497331200], [120793643843967159174, 661020604269309440], [-98689262780270850048, -1605381071927762688], [465875233060975622920, -74550402790777728], [22328306135394127308, 2510761347857614336], [179069623743012944962, -1671704639051703552], [514488917574765912692, -6586655579981568], [-142633718474770865776, -2723190290411131008], [-197867444015226417750, -1160368331655642112], [159760616337031646836, -536901130851648768], [-369771798897973624752, 1986165660568359680], [503298209497458819794, 1172375166741318144], [202981771997553381354, -562907437045645440], [-55279961474963720868, 2596570607797106432], [168038495127537153480, -3907918615848844032], [187470866987741886156, -2379642026941504768], [610315150928476153628, 197067090426748416], [428400320232740982664, -1321780005211489920], [216481281408601509566, -333139087957653504], [19919805930898500654, 1722032657236572160], [-69832784216348922312, -136051399691939072], [80495612359967014576, -1551728806295087232], [-252389039904633898044, -5922729196012796416], [-531001635238648567732, -4582907726902958592], [49777562003693627664, 159306131826255360], [-1056376964927480067086, 1113691607846136576], [-687254204814792533118, 2967316688661358080], [-489285514882725374376, -5409704953160132864], [-17526089914218363862, 4013391928392926208], [440428201041564428274, 6249719232451164800], [112733766697464846324, 4961968624438838784], [-850871486187950764858, 3258628363625713920], [25984204610722226308, 1628608649814950400], [-862187042447547763014, -465370072226362752], [159858501390871348966, -1245364748946312192], [488123949780810371440, 4238351422853913216], [419956059316616959644, 9719296778816961536], [490268506485996176054, 3333802671611000064], [-367028714245092080654, -8119537782534125568], [-886427258790474825282, -6323685089709582080], [-878850096078877855804, 6886508358246898176], [-145329996905264072178, 1006715515017078912], [-527159584283460678630, 3887137949032872448], [-365492193240389740988, -9784349689352516352], [-936463541556271649094, 3665339176893695872], [758404825223752686398, -3731879160984651264], [357774662419944602380, 3483016880019328512], [-297537425127426394106, -3250983371075665920], [-613492257457506078256, -1052188951073590656], [-486297713431614090290, 5411073316509315072], [-539700732890634085256, 3586854765336704640], [589492987281125658756, 12045878441229730048], [1551368485502830910510, 6867103937659706880], [-1159346951930627837206, -2222799158971173888], [-394407137496541630284, 9074019879713027584], [910309311412692481152, 2095674214703795968], [-895830254132407421512, 1281479722877632896], [2420298535012237889064, -5288376084079800064], [840315562808051232854, -15942578884277165568], [1065879262786266716980, -2081758063695499008], [689998444445811278736, 4830382343682153984], [1217535645974234523694, 6105051553458977280], [-53209977227190850518, -946839401868615296], [-1112875745184981059896, -176122823081060736], [744682746835950934050, -12867207490213562880], [193458284657788169934, 21113457577241636992], [509358632046949340460, -14480617708901142528], [-2252129532798260658906, -14364712192637288960], [1775090604608663696748, 3565355696095502336], [-79239220110879755966, 15510443863812019200], [929299411502626420350, -9210058245713392000], [3138834387900366955952, -839921554467216000], [1556885538995363766378, -6513822264049480576], [3295964829247769354940, 6496459569787411200], [1229649511025715567292, 4811207274555081984], [-2390246990419893800234, 9594514757209162752], [1533611098126458759762, 23223682584770742144], [1216892423029145504384, -19032456832949955456], [-470672036245654274484, -17534743741962841088], [-1667396680690697636260, 5899557284325197568], [2994557865338865967198, 12755048932501655040], [-2651210530981240496940, 4846480602189569792], [-594299029450933441858, 12433951686299035392], [-2415461217995250909288, 10466645010453116672], [-897874175648945811350, -29148882693650210304], [2111579819481770452080, -16077089324817624064], [203379120550576554102, -19343432882156907648], [3252955016971486455426, -10043739353256056576], [3588109213708987314844, -3507640063442208000], [5515346351944510484760, 13108822260092431872], [757505921697229635722, -34181361935736265728], [-441817113760814835756, 36477287855524570624], [3798946617228129213792, -10313097738874051840], [-509659544812375611458, 30979660654805925888], [-535333651859947086126, 42082267416897135104], [-2153373655516255275724, 12277153274925855744], [-6227190183232812271226, -1169693662892166144], [-3613334500511070563106, 12200083569666383232], [79021779445331684080, -6244268938093874304], [1402811904054804833430, 8028326559370486016], [102088055946751566194, 52073052043479086592], [-1211407051613966283580, 41058160544297606400], [-1006147405842552930716, -744023364395385600], [-459735596117886672288, -7636536268065212416], [1574202082913055115866, 43184515278561812352], [-1597330314037472325058, 51195311903922151680], [-841798315804635969822, 13542904212772366720], [2749309635708659666960, 1608823190309454720], [-6116923114772377623012, 22411678791946724864], [7677598030431690049580, 5683858531021329408], [6165834068376073426212, 20829508909410495744], [-5049232941843642018994, 44880925941861267456], [-1641520820954402347554, 37464881043769810432], [-8183563747554876278710, -18668826387994309632], [-10707201326611288433792, 8814508425976786560], [1410670503889165476730, 2284568210443493376], [4499930889331746811974, 12696440552035318016], [-1294055509638871631322, 20155476954081458048], [-536858701100127558568, 2753701250281960320], [-3153009730229021511774, -47640219009672707968], [-3424096332229699054620, -71741980564937137920], [-4312533993679335084010, -85997981225678775552], [8336455367070315368116, -2816345626444334592], [-5030644303771534335024, -26989735730835251456], [4494275138112081619626, -50362517239097837952], [-4765694828160250721596, 44768132088110353152], [1926570363011882730646, -10497469490766669312], [13014803779166767410126, 13561839267032768384], [-1586307658783745691872, 55690765219694542464], [11710229849611423086182, 5016095928144525312], [9225517940411425282566, -29902149730116584448], [-5569613360228610164448, -74942751502964643328], [-1856187602702371409652, 121781310452341602816], [-10094363894895578361234, 37039565866124109568], [2915788738283651914056, 2409342418938501632], [-2989135106647975629782, -65989213848203673600], [-7284616321963192203222, -65691867710706082304], [2373461167586104817136, 8433607829618039808], [-2852263334567107066212, -29206701976055858432], [-5068776517182051113540, -106494335848423484928], [2229315010656983892982, -19194542502174231552], [-9623080483250761641582, 27833792357075461760], [6783887489196847511176, 70601827650946042752], [9489565933851232257914, 15505742374273861632], [6777496068906889369188, -89894412860668822784], [13137151052796724161452, -47823926416118754048], [-2931743602035948033648, 77839262384862174208], [-4644387043955950791978, 69966807283748797312], [21004080093313183834088, -20297513919792184704], [6726607568817586422514, 110436042388409185536], [14163524440469480283732, -84514855637400832768], [9208349058622875910560, -16969229766637857792], [9526519706922947288158, -103849565890172829696], [-12479290517086763162094, 52369091570422991616], [-9225637932318343714970, 166223586260961372672], [-5458536028085682868578, -15169177932041824640], [14743785117395403228150, -29660735885805135104], [1248101546843364321976, 149153733107661886848], [6666942838354053347358, -155992238875446016000], [791496591276617535524, -66204393226139102976], [-21224995750074655227240, 24982009706806265856], [-18281966693319143657632, 19246732479818787456], [2531617663775134411930, -207504853856295821568], [3874796576395055695780, -69883008675488354304], [8080112523554387016480, 138698620845153025792], [-7789564915818427317502, -130740152265044923392], [18393559821047767653306, 39451031852933194112], [-20548165327916229045396, -124951755936056150016], [-22336808130638650430036, -98584650845793886464], [5585531986611509209560, -29141314520764877312], [-18486175944166045784186, -66045227593934661120], [-7929417467223716866000, 103683385137878317440], [10022900192468470655658, 153615159538703089408], [-9795156060063224710804, -29576401571325125376], [-1694745805624379038602, 275887533025283985536], [-33433865845556003418514, -62320452438517323264], [-31164301831889912742882, 34695208947668891904], [4620936549557034674464, 126536024574968017536], [18906179550777443139174, -115620047868855106304], [-38212524011551006310778, 61868221835858861952], [430921040896830330776, 10836799225308814464], [8325069216320487746818, -252160385821548238080], [29580693994912043094354, -120157092230922576128], [-19502397156393910276916, 53697778836708176640], [-26959419029215147464252, -63619144326204346112], [-12205791764560013672402, 235480818193676642304], [-3394063044524807904150, 207176203156957350272], [19172053032752436892452, 10006338515599627008], [-1875763816994769139036, -119595013517758641408], [2639824106206401841270, -39359119592184634368], [-1879322162962028264082, 289729061255946243456], [-7006642565677315541568, 280551253444744768512], [-22375599006133663128440, -220297631410328658048], [-19125200716976660676786, 150571289655444178176], [-35292094323952157953272, 35786799654514034944], [-6641532108933645959874, -190918253677656289664], [35093296886304876138826, 2279621525570085888], [-26377078936688256172464, 12740986875873509888], [-21439409052553189651332, -37121893591853331712], [-41982285936858632484842, -51875834871886580736], [6088055309129006446770, 346098247086754855552], [-23692202393794057454868, -81052206339683652352], [-44653298440281826122630, -131518070431649717760], [-6177034232899699799716, -288944013000622848768], [30134319703252172770968, -28921956274215533312]]
